==> opentoonz-dmo_1.5.0.orig.tar.xz: opentoonz-1.5.0/toonz/sources/translations/spanish/image.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_UY">
<context>
    <name>AviWriterProperties</name>
    <message>
        <location filename="../../image/avi/tiio_avi.cpp" line="1182"/>
        <source>Codec</source>
        <translation>Compresor</translation>
    </message>
    <message>
        <location filename="../../image/avi/tiio_avi.cpp" line="1183"/>
        <source>Uncompressed</source>
        <translation>Sin compresión</translation>
    </message>
</context>
<context>
    <name>GifWriterProperties</name>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="257"/>
        <source>Scale</source>
        <translation>Escala</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="258"/>
        <source>Looping</source>
        <translation>Ciclo</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="259"/>
        <source>Generate Palette</source>
        <translation>Generar paleta</translation>
    </message>
</context>
<context>
    <name>Mp4WriterProperties</name>
    <message>
        <location filename="../../image/ffmpeg/tiio_mp4.cpp" line="234"/>
        <source>Quality</source>
        <translation>Calidad</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_mp4.cpp" line="235"/>
        <source>Scale</source>
        <translation>Escala</translation>
    </message>
</context>
<context>
    <name>PngWriterProperties</name>
    <message>
        <location filename="../../image/png/tiio_png.cpp" line="757"/>
        <source>Alpha Channel</source>
        <translation>Canal alfa</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../image/ffmpeg/tiio_ffmpeg.cpp" line="177"/>
        <source>FFmpeg timed out.
Please check the file for errors.
If the file doesn&apos;t play or is incomplete, 
Please try raising the FFmpeg timeout in Preferences.</source>
        <translation>Tiempo de espera excedido para FFmpeg.
Por favor comprobar errores en el archivo.
Si no se reproduce o se encuentra incompleto, 
intentar aumentar el tiempo de espera en las Preferencias.</translation>
    </message>
</context>
<context>
    <name>SgiWriterProperties</name>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1229"/>
        <source>Bits Per Pixel</source>
        <translation>Bits por píxel</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1230"/>
        <source>24 bits</source>
        <translation>24 bits</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1231"/>
        <source>32 bits</source>
        <translation>32 bits</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1232"/>
        <source>48 bits</source>
        <translation>48 bits</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1233"/>
        <source>64 bits</source>
        <translation>64 bits</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1234"/>
        <source>8 bits (Greyscale)</source>
        <translation>8 bits (escala de grises)</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1235"/>
        <source>Endianess</source>
        <translation>Orden</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1236"/>
        <source>Big Endian</source>
        <translation>Mayor al inicio (big endian)</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1237"/>
        <source>Little Endian</source>
        <translation>Menor al inicio (little endian)</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1238"/>
        <source>RLE-Compressed</source>
        <translation>Compresión RLE</translation>
    </message>
</context>
<context>
    <name>SpriteWriterProperties</name>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="313"/>
        <source>Top Padding</source>
        <translation>Relleno superior</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="314"/>
        <source>Bottom Padding</source>
        <translation>Relleno inferior</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="315"/>
        <source>Left Padding</source>
        <translation>Relleno izquierdo</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="316"/>
        <source>Right Padding</source>
        <translation>Relleno derecho</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="317"/>
        <source>Scale</source>
        <translation>Escala</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="318"/>
        <source>Format</source>
        <translation>Formato</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="319"/>
        <source>Grid</source>
        <translation>Cuadrícula</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="320"/>
        <source>Vertical</source>
        <translation>Vertical</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="321"/>
        <source>Horizontal</source>
        <translation>Horizontal</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="322"/>
        <source>Individual</source>
        <translation>Individual</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="323"/>
        <source>Trim Empty Space</source>
        <translation>Recortar espacios vacíos</translation>
    </message>
</context>
<context>
    <name>SvgWriterProperties</name>
    <message>
        <location filename="../../image/svg/tiio_svg.cpp" line="1969"/>
        <source>Stroke Mode</source>
        <translation>Modo de vectorización</translation>
    </message>
    <message>
        <location filename="../../image/svg/tiio_svg.cpp" line="1970"/>
        <source>Outline Quality</source>
        <translation>Calidad de contornos</translation>
    </message>
    <message>
        <location filename="../../image/svg/tiio_svg.cpp" line="1971"/>
        <source>Centerline</source>
        <translation>Líneas</translation>
    </message>
    <message>
        <location filename="../../image/svg/tiio_svg.cpp" line="1972"/>
        <source>Outline</source>
        <translation>Contornos</translation>
    </message>
    <message>
        <location filename="../../image/svg/tiio_svg.cpp" line="1973"/>
        <source>High</source>
        <translation>Alta</translation>
    </message>
    <message>
        <location filename="../../image/svg/tiio_svg.cpp" line="1974"/>
        <source>Medium</source>
        <translation>Media</translation>
    </message>
    <message>
        <location filename="../../image/svg/tiio_svg.cpp" line="1975"/>
        <source>Low</source>
        <translation>Baja</translation>
    </message>
</context>
<context>
    <name>TgaWriterProperties</name>
    <message>
        <location filename="../../image/tga/tiio_tga.cpp" line="523"/>
        <source>Bits Per Pixel</source>
        <translation>Bits por píxel</translation>
    </message>
    <message>
        <location filename="../../image/tga/tiio_tga.cpp" line="524"/>
        <source>16 bits</source>
        <translation>16 bits</translation>
    </message>
    <message>
        <location filename="../../image/tga/tiio_tga.cpp" line="525"/>
        <source>24 bits</source>
        <translation>24 bits</translation>
    </message>
    <message>
        <location filename="../../image/tga/tiio_tga.cpp" line="526"/>
        <source>32 bits</source>
        <translation>32 bits</translation>
    </message>
    <message>
        <location filename="../../image/tga/tiio_tga.cpp" line="527"/>
        <source>Compression</source>
        <translation>Compresión</translation>
    </message>
</context>
<context>
    <name>TifWriterProperties</name>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="730"/>
        <source>Byte Ordering</source>
        <translation>Orden de bytes</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="731"/>
        <source>Compression Type</source>
        <translation>Tipo de compresión</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="732"/>
        <source>Bits Per Pixel</source>
        <translation>Bits por píxel</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="733"/>
        <source>24(RGB)</source>
        <translation>24 (color)</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="734"/>
        <source>48(RGB)</source>
        <translation>48 (color)</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="735"/>
        <source> 1(BW)</source>
        <translation> 1 (blanco y negro)</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="736"/>
        <source> 8(GREYTONES)</source>
        <translation> 8 (escala de grises)</translation>
    </message>
    <message>
        <source>32(RGBM)</source>
        <translation type="vanished">32 (color + alfa)</translation>
    </message>
    <message>
        <source>64(RGBM)</source>
        <translation type="vanished">64 (color + alfa)</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="737"/>
        <source>32(RGBA)</source>
        <translation>32 (color + alfa)</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="738"/>
        <source>64(RGBA)</source>
        <translation>64 (color + alfa)</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="739"/>
        <source>Orientation</source>
        <translation>Orientación</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="740"/>
        <source>Top Left</source>
        <translation>Superior izquierda</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="741"/>
        <source>Top Right</source>
        <translation>Superior derecha</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="742"/>
        <source>Bottom Right</source>
        <translation>Inferior derecha</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="743"/>
        <source>Bottom Left</source>
        <translation>Inferior izquierda</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="744"/>
        <source>Left Top</source>
        <translation>Izquierda superior</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="745"/>
        <source>Left Bottom</source>
        <translation>Izquierda inferior</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="746"/>
        <source>Right Top</source>
        <translation>Derecha superior</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="747"/>
        <source>Right Bottom</source>
        <translation>Derecha inferior</translation>
    </message>
</context>
<context>
    <name>WebmWriterProperties</name>
    <message>
        <location filename="../../image/ffmpeg/tiio_webm.cpp" line="235"/>
        <source>Quality</source>
        <translation>Calidad</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_webm.cpp" line="236"/>
        <source>Scale</source>
        <translation>Escala</translation>
    </message>
</context>
</TS>

==> opentoonz-dmo_1.6.0.orig.tar.xz: opentoonz-1.6.0/toonz/sources/translations/spanish/image.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_UY">
<context>
    <name>AviWriterProperties</name>
    <message>
        <location filename="../../image/avi/tiio_avi.cpp" line="1182"/>
        <source>Codec</source>
        <translation>Compresor</translation>
    </message>
    <message>
        <location filename="../../image/avi/tiio_avi.cpp" line="1183"/>
        <source>Uncompressed</source>
        <translation>Sin compresión</translation>
    </message>
</context>
<context>
    <name>ExrWriterProperties</name>
    <message>
        <location filename="../../image/exr/tiio_exr.cpp" line="227"/>
        <source>Bits Per Pixel</source>
        <translatorcomment>Bits por píxel</translatorcomment>
        <translation>Bits por píxel</translation>
    </message>
    <message>
        <location filename="../../image/exr/tiio_exr.cpp" line="228"/>
        <source>48(RGB Half Float)</source>
        <translation>48 (color decimal medio)</translation>
    </message>
    <message>
        <location filename="../../image/exr/tiio_exr.cpp" line="229"/>
        <source>64(RGBA Half Float)</source>
        <translation>64 (color + alfa decimal medio)</translation>
    </message>
    <message>
        <location filename="../../image/exr/tiio_exr.cpp" line="231"/>
        <source>Compression Type</source>
        <translation>Tipo de compresión</translation>
    </message>
    <message>
        <location filename="../../image/exr/tiio_exr.cpp" line="233"/>
        <source>No compression</source>
        <translation>Sin compresión</translation>
    </message>
    <message>
        <location filename="../../image/exr/tiio_exr.cpp" line="236"/>
        <source>Run Length Encoding (RLE)</source>
        <translation>Compresión Run Length (RLE)</translation>
    </message>
    <message>
        <location filename="../../image/exr/tiio_exr.cpp" line="239"/>
        <source>ZIP compression per Scanline (ZIPS)</source>
        <translation>Compresión ZIP por línea de barrido (ZIPS)</translation>
    </message>
    <message>
        <location filename="../../image/exr/tiio_exr.cpp" line="242"/>
        <source>ZIP compression per scanline band (ZIP)</source>
        <translation>Compresión ZIP por banda de línea de barrido (ZIP)</translation>
    </message>
    <message>
        <location filename="../../image/exr/tiio_exr.cpp" line="245"/>
        <source>PIZ-based wavelet compression (PIZ)</source>
        <translation>Compresión de ondículas basada en PIZ (PIZ)</translation>
    </message>
    <message>
        <location filename="../../image/exr/tiio_exr.cpp" line="247"/>
        <source>Storage Type</source>
        <translation>Tipo de almacenamiento</translation>
    </message>
    <message>
        <location filename="../../image/exr/tiio_exr.cpp" line="248"/>
        <source>Scan-line based</source>
        <translation>Basado en líneas de barrido</translation>
    </message>
    <message>
        <location filename="../../image/exr/tiio_exr.cpp" line="249"/>
        <source>Tile based</source>
        <translation>Basado en celdas</translation>
    </message>
</context>
<context>
    <name>GifWriterProperties</name>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="310"/>
        <source>Global Palette</source>
        <translation>Paleta global</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="311"/>
        <source>Global Palette + Sierra Dither</source>
        <translation>Paleta global + difuminado Sierra</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="312"/>
        <source>Global Palette + Bayer2 Dither</source>
        <translation>Paleta global + difuminado Bayer 2</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="313"/>
        <source>Global Palette + Bayer1 Dither</source>
        <translation>Paleta global + difuminado Bayer 1</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="314"/>
        <source>Diff Palette</source>
        <translation>Paleta diferencial</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="315"/>
        <source>Diff Palette + Sierra Dither</source>
        <translation>Paleta diferencial + difuminado Sierra</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="316"/>
        <source>Diff Palette + Bayer2 Dither</source>
        <translation>Paleta diferencial + difuminado Bayer 2</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="317"/>
        <source>Diff Palette + Bayer1 Dither</source>
        <translation>Paleta diferencial + difuminado Bayer 1</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="318"/>
        <source>New Pal Per Frame</source>
        <translation>Paleta por fotograma</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="319"/>
        <source>New Pal Per Frame + Sierra Dither</source>
        <translation>Paleta por fotograma + difuminado Sierra</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="320"/>
        <source>New Pal Per Frame + Bayer2 Dither</source>
        <translation>Paleta por fotograma + difuminado Bayer 2</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="321"/>
        <source>New Pal Per Frame + Bayer1 Dither</source>
        <translation>Paleta por fotograma + difuminado Bayer 1</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="322"/>
        <source>Opaque, Dither, 256 Colors Only</source>
        <translation>Opaco, difuminado, sólo 256 colores</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="335"/>
        <source>Scale</source>
        <translation>Escala</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="336"/>
        <source>Looping</source>
        <translation>Ciclo</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="337"/>
        <source>Mode</source>
        <translation>Modo</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="338"/>
        <source>Max Colors</source>
        <translation>Colores máximos</translation>
    </message>
    <message>
        <source>Generate Palette</source>
        <translation type="vanished">Generar paleta</translation>
    </message>
</context>
<context>
    <name>Mp4WriterProperties</name>
    <message>
        <location filename="../../image/ffmpeg/tiio_mp4.cpp" line="234"/>
        <source>Quality</source>
        <translation>Calidad</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_mp4.cpp" line="235"/>
        <source>Scale</source>
        <translation>Escala</translation>
    </message>
</context>
<context>
    <name>PngWriterProperties</name>
    <message>
        <location filename="../../image/png/tiio_png.cpp" line="757"/>
        <source>Alpha Channel</source>
        <translation>Canal alfa</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../image/ffmpeg/tiio_ffmpeg.cpp" line="213"/>
        <source>FFmpeg returned error-code: %1</source>
        <translation>Código de error devuelto por FFmpeg: %1</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_ffmpeg.cpp" line="217"/>
        <source>FFmpeg timed out.
Please check the file for errors.
If the file doesn&apos;t play or is incomplete, 
Please try raising the FFmpeg timeout in Preferences.</source>
        <translation>Tiempo de espera excedido para FFmpeg.
Por favor comprobar errores en el archivo.
Si no se reproduce o se encuentra incompleto, 
intentar aumentar el tiempo de espera en las Preferencias.</translation>
    </message>
</context>
<context>
    <name>SgiWriterProperties</name>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1229"/>
        <source>Bits Per Pixel</source>
        <translation>Bits por píxel</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1230"/>
        <source>24 bits</source>
        <translation>24 bits</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1231"/>
        <source>32 bits</source>
        <translation>32 bits</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1232"/>
        <source>48 bits</source>
        <translation>48 bits</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1233"/>
        <source>64 bits</source>
        <translation>64 bits</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1234"/>
        <source>8 bits (Greyscale)</source>
        <translation>8 bits (escala de grises)</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1235"/>
        <source>Endianess</source>
        <translation>Orden</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1236"/>
        <source>Big Endian</source>
        <translation>Mayor al inicio (big endian)</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1237"/>
        <source>Little Endian</source>
        <translation>Menor al inicio (little endian)</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1238"/>
        <source>RLE-Compressed</source>
        <translation>Compresión RLE</translation>
    </message>
</context>
<context>
    <name>SpriteWriterProperties</name>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="313"/>
        <source>Top Padding</source>
        <translation>Relleno superior</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="314"/>
        <source>Bottom Padding</source>
        <translation>Relleno inferior</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="315"/>
        <source>Left Padding</source>
        <translation>Relleno izquierdo</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="316"/>
        <source>Right Padding</source>
        <translation>Relleno derecho</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="317"/>
        <source>Scale</source>
        <translation>Escala</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="318"/>
        <source>Format</source>
        <translation>Formato</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="319"/>
        <source>Grid</source>
        <translation>Cuadrícula</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="320"/>
        <source>Vertical</source>
        <translation>Vertical</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="321"/>
        <source>Horizontal</source>
        <translation>Horizontal</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="322"/>
        <source>Individual</source>
        <translation>Individual</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="323"/>
        <source>Trim Empty Space</source>
        <translation>Recortar espacios vacíos</translation>
    </message>
</context>
<context>
    <name>SvgWriterProperties</name>
    <message>
        <location filename="../../image/svg/tiio_svg.cpp" line="1969"/>
        <source>Stroke Mode</source>
        <translation>Modo de vectorización</translation>
    </message>
    <message>
        <location filename="../../image/svg/tiio_svg.cpp" line="1970"/>
        <source>Outline Quality</source>
        <translation>Calidad de contornos</translation>
    </message>
    <message>
        <location filename="../../image/svg/tiio_svg.cpp" line="1971"/>
        <source>Centerline</source>
        <translation>Líneas</translation>
    </message>
    <message>
        <location filename="../../image/svg/tiio_svg.cpp" line="1972"/>
        <source>Outline</source>
        <translation>Contornos</translation>
    </message>
    <message>
        <location filename="../../image/svg/tiio_svg.cpp" line="1973"/>
        <source>High</source>
        <translation>Alta</translation>
    </message>
    <message>
        <location filename="../../image/svg/tiio_svg.cpp" line="1974"/>
        <source>Medium</source>
        <translation>Media</translation>
    </message>
    <message>
        <location filename="../../image/svg/tiio_svg.cpp" line="1975"/>
        <source>Low</source>
        <translation>Baja</translation>
    </message>
</context>
<context>
    <name>TgaWriterProperties</name>
    <message>
        <location filename="../../image/tga/tiio_tga.cpp" line="523"/>
        <source>Bits Per Pixel</source>
        <translation>Bits por píxel</translation>
    </message>
    <message>
        <location filename="../../image/tga/tiio_tga.cpp" line="524"/>
        <source>16 bits</source>
        <translation>16 bits</translation>
    </message>
    <message>
        <location filename="../../image/tga/tiio_tga.cpp" line="525"/>
        <source>24 bits</source>
        <translation>24 bits</translation>
    </message>
    <message>
        <location filename="../../image/tga/tiio_tga.cpp" line="526"/>
        <source>32 bits</source>
        <translation>32 bits</translation>
    </message>
    <message>
        <location filename="../../image/tga/tiio_tga.cpp" line="527"/>
        <source>Compression</source>
        <translation>Compresión</translation>
    </message>
</context>
<context>
    <name>TifWriterProperties</name>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="730"/>
        <source>Byte Ordering</source>
        <translation>Orden de bytes</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="731"/>
        <source>Compression Type</source>
        <translation>Tipo de compresión</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="732"/>
        <source>Bits Per Pixel</source>
        <translation>Bits por píxel</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="733"/>
        <source>24(RGB)</source>
        <translation>24 (color)</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="734"/>
        <source>48(RGB)</source>
        <translation>48 (color)</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="735"/>
        <source> 1(BW)</source>
        <translation> 1 (blanco y negro)</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="736"/>
        <source> 8(GREYTONES)</source>
        <translation> 8 (escala de grises)</translation>
    </message>
    <message>
        <source>32(RGBM)</source>
        <translation type="vanished">32 (color + alfa)</translation>
    </message>
    <message>
        <source>64(RGBM)</source>
        <translation type="vanished">64 (color + alfa)</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="737"/>
        <source>32(RGBA)</source>
        <translation>32 (color + alfa)</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="738"/>
        <source>64(RGBA)</source>
        <translation>64 (color + alfa)</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="739"/>
        <source>Orientation</source>
        <translation>Orientación</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="740"/>
        <source>Top Left</source>
        <translation>Superior izquierda</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="741"/>
        <source>Top Right</source>
        <translation>Superior derecha</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="742"/>
        <source>Bottom Right</source>
        <translation>Inferior derecha</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="743"/>
        <source>Bottom Left</source>
        <translation>Inferior izquierda</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="744"/>
        <source>Left Top</source>
        <translation>Izquierda superior</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="745"/>
        <source>Left Bottom</source>
        <translation>Izquierda inferior</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="746"/>
        <source>Right Top</source>
        <translation>Derecha superior</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="747"/>
        <source>Right Bottom</source>
        <translation>Derecha inferior</translation>
    </message>
</context>
<context>
    <name>WebmWriterProperties</name>
    <message>
        <location filename="../../image/ffmpeg/tiio_webm.cpp" line="235"/>
        <source>Quality</source>
        <translation>Calidad</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_webm.cpp" line="236"/>
        <source>Scale</source>
        <translation>Escala</translation>
    </message>
</context>
</TS>
